******
GITHUB
******

.. program-output:: lftools github --help

Commands
========

create-repo
-----------

.. program-output:: lftools github create-repo --help

create-team
-----------

.. program-output:: lftools github create-team --help


list
----

.. program-output:: lftools github list --help


update-repo
-----------

.. program-output:: lftools github update-repo --help


submit-pr
---------

.. program-output:: lftools github submit-pr --help


user
----

.. program-output:: lftools github user --help


votes
-----

.. program-output:: lftools github votes --help



API requires a [github] or [github.OrgName] section in ~/.config/lftools/lftools.ini:

.. code-block:: bash

   [github] or [github.orgName]
   token = REDACTED

